<?php
/**
 * A database wrapper for user points classes
 *
 * @author		Roland Haeder <webmaster@ship-simu.org>
 * @version		0.0.0
 * @copyright	Copyright (c) 2007, 2008 Roland Haeder, 2009 - 2011 Core Developer Team
 * @license		GNU GPL 3.0 or any newer version
 * @link		http://www.ship-simu.org
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
class UserPointsDatabaseWrapper extends BaseDatabaseWrapper implements BookablePointsWrapper {
	/**
	 * Constants for database table names
	 */
	const DB_TABLE_USER_POINTS = 'user_points';

	/**
	 * Name of the user->points column
	 */
	const DB_COLUMN_POINTS_UID = 'points_uid';

	/**
	 * Name of the points column
	 */
	const DB_COLUMN_POINTS = 'points';

	/**
	 * Protected constructor
	 *
	 * @return	void
	 */
	protected function __construct () {
		// Call parent constructor
		parent::__construct(__CLASS__);
	}

	/**
	 * Creates an instance of this database wrapper by a provided user class
	 *
	 * @return	$wrapperInstance	An instance of the created wrapper class
	 */
	public static final function createUserPointsDatabaseWrapper () {
		// Get a new instance
		$wrapperInstance = new UserPointsDatabaseWrapper();

		// Set (primary!) table name
		$wrapperInstance->setTableName(self::DB_TABLE_USER_POINTS);

		// Return the instance
		return $wrapperInstance;
	}

	/**
	 * Inserts the given points for the given user in the database
	 *
	 * @param	$pointsInstance		An instance of a user class
	 * @return	void
	 */
	public function insertUserPoints (BookablePoints $pointsInstance) {
		// Generate a data set for the request
		$dataSetInstance = ObjectFactory::createObjectByConfiguredName('dataset_criteria_class', array(self::DB_TABLE_USER_POINTS));

		// Set the primary key
		$dataSetInstance->setUniqueKey(self::DB_COLUMN_POINTS_UID);

		// Add registration elements to the dataset
		$pointsInstance->addElementsToDataSet($dataSetInstance);

		// "Insert" this request instance completely into the database
		$this->queryInsertDataSet($dataSetInstance);
	}

	/**
	 * Updates an user database entry with given result
	 *
	 * @param	$resultInstance		An instance of a Updateable database result
	 * @return	void
	 */
	public function doUpdateByResult (UpdateableResult $resultInstance) {
		// Generate a data set object
		$dataSetInstance = ObjectFactory::createObjectByConfiguredName('dataset_criteria_class', array(self::DB_TABLE_USER_POINTS));

		// Add all update criteria to the database set
		$resultInstance->addElementsToDataSet($dataSetInstance);

		// Add seach criteria
		$dataSetInstance->setSearchInstance($resultInstance->getUpdateInstance()->getSearchInstance());

		// Set the primary key
		$dataSetInstance->setUniqueKey(self::DB_COLUMN_POINTS_UID);

		// "Update" this request with the database
		$this->getDatabaseInstance()->queryUpdateDataSet($dataSetInstance);
	}
}

// [EOF]
?>
